==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/HttpProxyConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Configurations for provisioning the cluster with HTTP proxy servers.
 * @property httpProxy The HTTP proxy server endpoint to use.
 * @property httpsProxy The HTTPS proxy server endpoint to use.
 * @property noProxy The endpoints that should not go through proxy.
 * @property password Password to use for connecting to proxy server
 * @property trustedCa Alternative CA cert to use for connecting to proxy servers.
 * @property username Username to use for connecting to proxy server
 */
public data class HttpProxyConfigArgs(
    public val httpProxy: Output<String>? = null,
    public val httpsProxy: Output<String>? = null,
    public val noProxy: Output<List<String>>? = null,
    public val password: Output<String>? = null,
    public val trustedCa: Output<String>? = null,
    public val username: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs.builder()
            .httpProxy(httpProxy?.applyValue({ args0 -> args0 }))
            .httpsProxy(httpsProxy?.applyValue({ args0 -> args0 }))
            .noProxy(noProxy?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .password(password?.applyValue({ args0 -> args0 }))
            .trustedCa(trustedCa?.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpProxyConfigArgs].
 */
@PulumiTagMarker
public class HttpProxyConfigArgsBuilder internal constructor() {
    private var httpProxy: Output<String>? = null

    private var httpsProxy: Output<String>? = null

    private var noProxy: Output<List<String>>? = null

    private var password: Output<String>? = null

    private var trustedCa: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value The HTTP proxy server endpoint to use.
     */
    @JvmName("nhbgupbweuqolhbo")
    public suspend fun httpProxy(`value`: Output<String>) {
        this.httpProxy = value
    }

    /**
     * @param value The HTTPS proxy server endpoint to use.
     */
    @JvmName("udxpvmovqfjixapc")
    public suspend fun httpsProxy(`value`: Output<String>) {
        this.httpsProxy = value
    }

    /**
     * @param value The endpoints that should not go through proxy.
     */
    @JvmName("teijiwgnqldqafbh")
    public suspend fun noProxy(`value`: Output<List<String>>) {
        this.noProxy = value
    }

    @JvmName("ixnldhensibnhkxe")
    public suspend fun noProxy(vararg values: Output<String>) {
        this.noProxy = Output.all(values.asList())
    }

    /**
     * @param values The endpoints that should not go through proxy.
     */
    @JvmName("hpuegsopeadritgu")
    public suspend fun noProxy(values: List<Output<String>>) {
        this.noProxy = Output.all(values)
    }

    /**
     * @param value Password to use for connecting to proxy server
     */
    @JvmName("vimexhurivkvncua")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value Alternative CA cert to use for connecting to proxy servers.
     */
    @JvmName("atihorxtacnwwjpv")
    public suspend fun trustedCa(`value`: Output<String>) {
        this.trustedCa = value
    }

    /**
     * @param value Username to use for connecting to proxy server
     */
    @JvmName("qoqlhvvbojhfhtcc")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value The HTTP proxy server endpoint to use.
     */
    @JvmName("clqxffgrvmbwhwju")
    public suspend fun httpProxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpProxy = mapped
    }

    /**
     * @param value The HTTPS proxy server endpoint to use.
     */
    @JvmName("budifptsvdvmokoc")
    public suspend fun httpsProxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpsProxy = mapped
    }

    /**
     * @param value The endpoints that should not go through proxy.
     */
    @JvmName("cvoopyorcedkfnlf")
    public suspend fun noProxy(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.noProxy = mapped
    }

    /**
     * @param values The endpoints that should not go through proxy.
     */
    @JvmName("moanhymtngfonlkn")
    public suspend fun noProxy(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.noProxy = mapped
    }

    /**
     * @param value Password to use for connecting to proxy server
     */
    @JvmName("mpqrgevghxbulxdr")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Alternative CA cert to use for connecting to proxy servers.
     */
    @JvmName("awbedyyslgejudtj")
    public suspend fun trustedCa(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedCa = mapped
    }

    /**
     * @param value Username to use for connecting to proxy server
     */
    @JvmName("oydonsclhlcgyvxa")
    public suspend fun username(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): HttpProxyConfigArgs = HttpProxyConfigArgs(
        httpProxy = httpProxy,
        httpsProxy = httpsProxy,
        noProxy = noProxy,
        password = password,
        trustedCa = trustedCa,
        username = username,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/HttpProxyConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Configurations for provisioning the cluster with HTTP proxy servers.
 * @property httpProxy The HTTP proxy server endpoint to use.
 * @property httpsProxy The HTTPS proxy server endpoint to use.
 * @property noProxy The endpoints that should not go through proxy.
 * @property password Password to use for connecting to proxy server
 * @property trustedCa Alternative CA cert to use for connecting to proxy servers.
 * @property username Username to use for connecting to proxy server
 */
public data class HttpProxyConfigArgs(
    public val httpProxy: Output<String>? = null,
    public val httpsProxy: Output<String>? = null,
    public val noProxy: Output<List<String>>? = null,
    public val password: Output<String>? = null,
    public val trustedCa: Output<String>? = null,
    public val username: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.HttpProxyConfigArgs.builder()
            .httpProxy(httpProxy?.applyValue({ args0 -> args0 }))
            .httpsProxy(httpsProxy?.applyValue({ args0 -> args0 }))
            .noProxy(noProxy?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .password(password?.applyValue({ args0 -> args0 }))
            .trustedCa(trustedCa?.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpProxyConfigArgs].
 */
@PulumiTagMarker
public class HttpProxyConfigArgsBuilder internal constructor() {
    private var httpProxy: Output<String>? = null

    private var httpsProxy: Output<String>? = null

    private var noProxy: Output<List<String>>? = null

    private var password: Output<String>? = null

    private var trustedCa: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value The HTTP proxy server endpoint to use.
     */
    @JvmName("etjywasonptgmaip")
    public suspend fun httpProxy(`value`: Output<String>) {
        this.httpProxy = value
    }

    /**
     * @param value The HTTPS proxy server endpoint to use.
     */
    @JvmName("vrimttmapgnhrver")
    public suspend fun httpsProxy(`value`: Output<String>) {
        this.httpsProxy = value
    }

    /**
     * @param value The endpoints that should not go through proxy.
     */
    @JvmName("jwbebqlcdawpjqql")
    public suspend fun noProxy(`value`: Output<List<String>>) {
        this.noProxy = value
    }

    @JvmName("hcucnfubgdixtokc")
    public suspend fun noProxy(vararg values: Output<String>) {
        this.noProxy = Output.all(values.asList())
    }

    /**
     * @param values The endpoints that should not go through proxy.
     */
    @JvmName("agwyauqpudfdlcjc")
    public suspend fun noProxy(values: List<Output<String>>) {
        this.noProxy = Output.all(values)
    }

    /**
     * @param value Password to use for connecting to proxy server
     */
    @JvmName("wnevqjfseyxgeiik")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value Alternative CA cert to use for connecting to proxy servers.
     */
    @JvmName("lkeygowddykyvafq")
    public suspend fun trustedCa(`value`: Output<String>) {
        this.trustedCa = value
    }

    /**
     * @param value Username to use for connecting to proxy server
     */
    @JvmName("fuhgavfxfuyrqgux")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value The HTTP proxy server endpoint to use.
     */
    @JvmName("shqkqgpnwrvcpnfs")
    public suspend fun httpProxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpProxy = mapped
    }

    /**
     * @param value The HTTPS proxy server endpoint to use.
     */
    @JvmName("yerkubcsxvxasvpk")
    public suspend fun httpsProxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpsProxy = mapped
    }

    /**
     * @param value The endpoints that should not go through proxy.
     */
    @JvmName("oglmtbhaccajjbwb")
    public suspend fun noProxy(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.noProxy = mapped
    }

    /**
     * @param values The endpoints that should not go through proxy.
     */
    @JvmName("rpvbbpinyvabthcv")
    public suspend fun noProxy(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.noProxy = mapped
    }

    /**
     * @param value Password to use for connecting to proxy server
     */
    @JvmName("xschqpnopenfpsrt")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Alternative CA cert to use for connecting to proxy servers.
     */
    @JvmName("qvioydructdgyrhj")
    public suspend fun trustedCa(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.trustedCa = mapped
    }

    /**
     * @param value Username to use for connecting to proxy server
     */
    @JvmName("sjajibbsfnikpgwr")
    public suspend fun username(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): HttpProxyConfigArgs = HttpProxyConfigArgs(
        httpProxy = httpProxy,
        httpsProxy = httpsProxy,
        noProxy = noProxy,
        password = password,
        trustedCa = trustedCa,
        username = username,
    )
}
